@@ -19,7 +19,9 @@
 unit tests for module modutils (module manipulation utilities)
 """
 
+import doctest
 import sys
+import warnings
 try:
     __file__
 except NameError:
@@ -116,8 +118,11 @@ class modpath_from_file_tc(ModutilsTestCase):
     """ given an absolute file path return the python module's path as a list """
 
     def test_knownValues_modpath_from_file_1(self):
-        self.assertEqual(modutils.modpath_from_file(modutils.__file__),
-                         ['logilab', 'common', 'modutils'])
+        with warnings.catch_warnings(record=True) as warns:
+            self.assertEqual(modutils.modpath_from_file(modutils.__file__),
+                             ['logilab', 'common', 'modutils'])
+            self.assertIn('you should avoid using modpath_from_file()',
+                          [str(w.message) for w in warns])
 
     def test_knownValues_modpath_from_file_2(self):
         self.assertEqual(modutils.modpath_from_file('unittest_modutils.py',
@@ -144,8 +149,9 @@ class file_from_modpath_tc(ModutilsTestCase):
     if it exists"""
 
     def test_site_packages(self):
-        self.assertEqual(path.realpath(modutils.file_from_modpath(['logilab', 'common', 'modutils'])),
-                         path.realpath(modutils.__file__.replace('.pyc', '.py')))
+        from pytz import tzinfo
+        self.assertEqual(path.realpath(modutils.file_from_modpath(['pytz', 'tzinfo'])),
+                         path.realpath(tzinfo.__file__.replace('.pyc', '.py')))
 
     def test_std_lib(self):
         from os import path
@@ -279,11 +285,11 @@ class get_modules_files_tc(ModutilsTestCase):
         self.assertTrue( hasattr(logilab.common, 'fileutils') )
         self.assertTrue( m is logilab.common.fileutils )
 
-from logilab.common.testlib import DocTest
-class ModuleDocTest(DocTest):
-    """test doc test in this module"""
-    from logilab.common import modutils as module
-del DocTest # necessary if we don't want it to be executed (we don't...)
+
+def load_tests(loader, tests, ignore):
+    from logilab.common import modutils
+    tests.addTests(doctest.DocTestSuite(modutils))
+    return tests
 
 
 if __name__ == '__main__':
