@@ -22,8 +22,10 @@ Unittests for table management
 
 import sys
 import os
-from cStringIO import StringIO
 
+from six.moves import range
+
+from logilab.common.compat import StringIO
 from logilab.common.testlib import TestCase, unittest_main
 from logilab.common.table import Table, TableStyleSheet, DocbookTableWriter, \
      DocbookRenderer, TableStyle, TableWriter, TableCellRenderer
@@ -64,14 +66,14 @@ class TableTC(TestCase):
 
     def test_indexation(self):
         """we should be able to use [] to access rows"""
-        self.assertTrue(self.table[0] == self.table.data[0])
-        self.assertTrue(self.table[1] == self.table.data[1])
+        self.assertEqual(self.table[0], self.table.data[0])
+        self.assertEqual(self.table[1], self.table.data[1])
 
     def test_iterable(self):
         """test iter(table)"""
         it = iter(self.table)
-        self.assertTrue(it.next() == self.table.data[0])
-        self.assertTrue(it.next() == self.table.data[1])
+        self.assertEqual(next(it), self.table.data[0])
+        self.assertEqual(next(it), self.table.data[1])
 
     def test_get_rows(self):
         """tests Table.get_rows()"""
@@ -307,7 +309,7 @@ class TableStyleSheetTC(TestCase):
         self.stylesheet.add_rowavg_rule((0, 2), 0, 0, 1)
         self.table.apply_stylesheet(self.stylesheet)
         val = self.table[0, 2]
-        self.assertTrue(int(val) == 15)
+        self.assertEqual(int(val), 15)
 
 
     def test_rowsum_rule(self):
@@ -317,7 +319,7 @@ class TableStyleSheetTC(TestCase):
         self.stylesheet.add_rowsum_rule((0, 2), 0, 0, 1)
         self.table.apply_stylesheet(self.stylesheet)
         val = self.table[0, 2]
-        self.assertTrue(val == 30)
+        self.assertEqual(val, 30)
 
 
     def test_colavg_rule(self):
@@ -329,7 +331,7 @@ class TableStyleSheetTC(TestCase):
         self.stylesheet.add_colavg_rule((2, 0), 0, 0, 1)
         self.table.apply_stylesheet(self.stylesheet)
         val = self.table[2, 0]
-        self.assertTrue(int(val) == 11)
+        self.assertEqual(int(val), 11)
 
 
     def test_colsum_rule(self):
@@ -341,7 +343,7 @@ class TableStyleSheetTC(TestCase):
         self.stylesheet.add_colsum_rule((2, 0), 0, 0, 1)
         self.table.apply_stylesheet(self.stylesheet)
         val = self.table[2, 0]
-        self.assertTrue(val == 22)
+        self.assertEqual(val, 22)
 
 
 
